AuthClient class

Example usage

Constructors

AuthClient(dynamic channel)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

login(String email, String password) Future<AuthResponse>
Login with existing credentials.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken(String refreshToken) Future<AuthResponse>
Returns the AuthResponse (new token + new refreshToken) or throws on failure.
register(String email, String password) Future<AuthResponse>
Register a new user.
toString() String
A string representation of this object.
inherited
validateToken(String token) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited