SqliteServiceClientWrapper class

DatabaseCore implementation that communicates via gRPC.

Wraps the gRPC client to provide the DatabaseCore interface. Used for select calls from the base query method; execute is overridden by SQLiteWrapperGRPC and does not reach here.

Implemented types

Constructors

SqliteServiceClientWrapper({required SqliteWrapperServiceClient client, required String dbName})

Properties

client SqliteWrapperServiceClient
final
dbName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
override
execute(String sql, List<Object?> params) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(String sql, List<Object?> params) Future<List<Map<String, dynamic>>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited