Sqlite3Database class

Sqlite3 database adapter implementing DatabaseCore. Wraps synchronous sqlite3 calls in async for uniform access.

Implemented types

Constructors

Sqlite3Database(Database _db)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
override
execute(String sql, List<Object?> params) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(String sql, List<Object?> params) Future<List<Map<String, dynamic>>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited