Databases class

Manages multiple named database connections. Maps dbName strings to DatabaseCore instances.

Constructors

Databases()

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add({required String name, required DatabaseCore db, bool useGRPC = false}) → void
get(String name) DatabaseCore?
getNames() List<String>
Return all db names
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String name) → void
toString() String
A string representation of this object.
inherited
useGRPC(String name) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited